==> pandoc-citeproc-0.14.4-8-armv7h.pkg.tar.xz: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-citeproc
version: 0.14.4
id: pandoc-citeproc-0.14.4-GrbDLVhzo2C4FQL978SLgA
key: pandoc-citeproc-0.14.4-GrbDLVhzo2C4FQL978SLgA
license: BSD-3-Clause
maintainer: jgm@berkeley.edu
author: John MacFarlane, Andrea Rossato
homepage: https://github.com/jgm/pandoc-citeproc
synopsis: Supports using pandoc with citeproc
description:
    The pandoc-citeproc library exports functions for
    using the citeproc system with pandoc.  It relies on
    citeproc-hs, a library for rendering
    bibliographic reference citations into a variety
    of styles using a macro language called Citation
    Style Language (CSL). More details on CSL can be
    found here: <http://citationstyles.org/>.
    .
    Currently this package includes a heavily revised
    copy of the citeproc-hs code. When citeproc-hs is
    updated to be compatible, this package will simply
    depend on citeproc-hs.
    .
    This package also contains an executable: pandoc-citeproc,
    which works as a pandoc filter, and
    also has a mode for converting bibliographic databases
    a YAML format suitable for inclusion in pandoc YAML
    metadata.
category: Text
abi: 67e1195d38852dd07aa1871afaa75b0e
exposed: True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style
hidden-modules: Text.CSL.Util Paths_pandoc_citeproc
                Text.CSL.Compat.Pandoc
import-dirs: /usr/lib/ghc-8.4.3/site-local/pandoc-citeproc-0.14.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/pandoc-citeproc-0.14.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-citeproc
hs-libraries: HSpandoc-citeproc-0.14.4-GrbDLVhzo2C4FQL978SLgA
depends:
    containers-0.5.11.0 directory-1.3.1.5 mtl-2.2.2 bytestring-0.10.8.2
    filepath-1.4.2 pandoc-types-1.17.5.1-4yrD8D7bgzNHhgJdUTEzaD
    pandoc-2.2.3.2-8fyR7zlgCdr3P9f0rl3267
    tagsoup-0.14.7-KTJ3O1jkqqV6ajaCVnh6SS
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    xml-conduit-1.8.0.1-DxwErWR0reB5khGDFuyeHG
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    yaml-0.10.2.0-DSueIRJplpxAtqTVD7QPVT
    hs-bibutils-6.6.0.0-EPnifPWXp9L7Ofj5S6ivGg
    text-icu-0.7.0.1-GQ0DM6OBTErByT1EmU06SY base-4.11.1.0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV parsec-3.1.13.0
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh time-1.8.0.2
abi-depends: containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             pandoc-types-1.17.5.1-4yrD8D7bgzNHhgJdUTEzaD=3e95e5c25491356b24a20ac98b02dd77
             pandoc-2.2.3.2-8fyR7zlgCdr3P9f0rl3267=c8772965fad4b10e5ecdcef19dcfdb3c
             tagsoup-0.14.7-KTJ3O1jkqqV6ajaCVnh6SS=f89d0de360f79f1fd3ea1a2c47b0a186
             aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             xml-conduit-1.8.0.1-DxwErWR0reB5khGDFuyeHG=bd95b655800102dc7b908f38a2a230b1
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=f590a47c94186759709b79b52a1e0710
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             yaml-0.10.2.0-DSueIRJplpxAtqTVD7QPVT=36781676fac911c6d784ba1d71fadb46
             hs-bibutils-6.6.0.0-EPnifPWXp9L7Ofj5S6ivGg=230d1914b99621634532eebd0a6a8573
             text-icu-0.7.0.1-GQ0DM6OBTErByT1EmU06SY=146441e6e65cb12937d91163213f0ec6
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html: /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-citeproc-0.14.4-12-armv7h.pkg.tar.xz: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-citeproc
version: 0.14.4
id: pandoc-citeproc-0.14.4-H1jODyD07aU5eYtSYIml6b
key: pandoc-citeproc-0.14.4-H1jODyD07aU5eYtSYIml6b
license: BSD-3-Clause
maintainer: jgm@berkeley.edu
author: John MacFarlane, Andrea Rossato
homepage: https://github.com/jgm/pandoc-citeproc
synopsis: Supports using pandoc with citeproc
description:
    The pandoc-citeproc library exports functions for
    using the citeproc system with pandoc.  It relies on
    citeproc-hs, a library for rendering
    bibliographic reference citations into a variety
    of styles using a macro language called Citation
    Style Language (CSL). More details on CSL can be
    found here: <http://citationstyles.org/>.
    .
    Currently this package includes a heavily revised
    copy of the citeproc-hs code. When citeproc-hs is
    updated to be compatible, this package will simply
    depend on citeproc-hs.
    .
    This package also contains an executable: pandoc-citeproc,
    which works as a pandoc filter, and
    also has a mode for converting bibliographic databases
    a YAML format suitable for inclusion in pandoc YAML
    metadata.
category: Text
abi: 9ef0d84c60b48f6f5af6f2e14f8d7c66
exposed: True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style
hidden-modules: Text.CSL.Util Paths_pandoc_citeproc
                Text.CSL.Compat.Pandoc
import-dirs: /usr/lib/ghc-8.4.3/site-local/pandoc-citeproc-0.14.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/pandoc-citeproc-0.14.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/pandoc-citeproc
hs-libraries: HSpandoc-citeproc-0.14.4-H1jODyD07aU5eYtSYIml6b
depends:
    containers-0.5.11.0 directory-1.3.1.5 mtl-2.2.2 bytestring-0.10.8.2
    filepath-1.4.2 pandoc-types-1.17.5.1-5Rw07t1cmdWHyALt8533QZ
    pandoc-2.2.3.2-DdpAiStCOJ1G9mNXAmUqPR
    tagsoup-0.14.7-KTJ3O1jkqqV6ajaCVnh6SS
    aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6 text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    xml-conduit-1.8.0.1-5ohagde3XnS66KAyeURTzg
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    yaml-0.10.2.0-1E1l9P3riHAMiARjtTYoy
    hs-bibutils-6.6.0.0-EPnifPWXp9L7Ofj5S6ivGg
    text-icu-0.7.0.1-GQ0DM6OBTErByT1EmU06SY base-4.11.1.0
    syb-0.7-2jW43lwzJV5e7EQvU8PxV parsec-3.1.13.0
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh time-1.8.0.2
abi-depends: containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             pandoc-types-1.17.5.1-5Rw07t1cmdWHyALt8533QZ=544cdb731fe2a75f68f91d0726f7e7b4
             pandoc-2.2.3.2-DdpAiStCOJ1G9mNXAmUqPR=59041546e3191b21a17df783ac1f092e
             tagsoup-0.14.7-KTJ3O1jkqqV6ajaCVnh6SS=f89d0de360f79f1fd3ea1a2c47b0a186
             aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6=22145541f26b56c63b48572ec79b9cbd
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             xml-conduit-1.8.0.1-5ohagde3XnS66KAyeURTzg=72d7457f4356ac39caa3b33875c7b19d
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=f590a47c94186759709b79b52a1e0710
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             yaml-0.10.2.0-1E1l9P3riHAMiARjtTYoy=4c3281149ef47585281e0340dc18c32b
             hs-bibutils-6.6.0.0-EPnifPWXp9L7Ofj5S6ivGg=230d1914b99621634532eebd0a6a8573
             text-icu-0.7.0.1-GQ0DM6OBTErByT1EmU06SY=146441e6e65cb12937d91163213f0ec6
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html: /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
